About the Copyright Holders
===========================

*   Copyright (c) 2021-2021 Yutaka Kabutoya

    Yutaka is now an employee of Amazon Web Services, but note that this
    package is outcome from Yutaka's private activity. Thus, this package
    is not officially supported by Amazon Web Services.

    Yutaka will open bigdata repositories aside from this package, see
    http://github.com/yutaka-kabu just in case.

Our Copyright Policy
====================

At this moment the source code, in its entirety, is the copyright of
Yutaka Kabutoya. I will organize the team to maintain and enhance
this package and share copyright with the team if others are interested
in contributing this package and make significant contributions on this
package.

Other licenses can be found in the LICENSE file.

License
=======

pandas-amazon-redshift is distributed under a 3-clause ("Simplified" or "New")
BSD license. Parts of pandas, NumPy, numpydoc, which all have
BSD-compatible licenses, are included. 
